import 'package:migrable/migration.dart';
import 'package:sqflite/sqflite.dart';
import 'package:sqflitecon/db.dart';

class Migrable {
  static void execute(List<Migration> migrations) async {
    onConfigure(database) async {
      await database.execute('PRAGMA foreign_keys = ON');
    }

    onCreate(database, version) {
      final batch = database.batch();

      migrations.forEach((migration) => {migration.up(batch)});
      batch.commit();
    }

    onUpgrade(database, oldVersion, newVersion) async {
      final batch = database.batch();

      for (var index = oldVersion; index < newVersion; index++) {
        final migration = migrations[index];

        migration.up(batch);
      }

      batch.commit();
    }

    if (migrations == null || migrations.isEmpty) {
      return;
    }

    await databaseConnection(
        version: migrations.length,
        onConfigure: onConfigure,
        onDowngrade: onDatabaseDowngradeDelete,
        onCreate: onCreate,
        onUpgrade: onUpgrade);
  }
}
